@@ -6,6 +6,8 @@
 
 #include <config.h>
 
+#include <asiolink/io_service_mgr.h>
+#include <asiolink/process_spawn.h>
 #include <cc/command_interpreter.h>
 #include <cc/data.h>
 #include <config/command_mgr.h>
@@ -241,6 +243,7 @@ ControlledDhcpv4Srv::commandLibReloadHandler(const string&, ConstElementPtr) {
         HookLibsCollection loaded = HooksManager::getLibraryInfo();
         HooksManager::prepareUnloadLibraries();
         static_cast<void>(HooksManager::unloadLibraries());
+        IOServiceMgr::instance().clearIOServices();
         bool multi_threading_enabled = true;
         uint32_t thread_count = 0;
         uint32_t queue_size = 0;
@@ -450,9 +453,10 @@ ControlledDhcpv4Srv::commandConfigSetHandler(const string&,
         LOG_FATAL(dhcp4_logger, DHCP4_CONFIG_UNRECOVERABLE_ERROR);
     }
 
-    /// Let postponed hook initializations to run.
+    /// Let postponed hook initializations run.
     try {
-        getIOService()->poll();
+        // Handle events registered by hooks using external IOService objects.
+        IOServiceMgr::instance().pollIOServices();
     } catch (const std::exception& ex) {
         std::ostringstream err;
         err << "Error initializing hooks: "
@@ -555,9 +559,22 @@ ControlledDhcpv4Srv::commandDhcpDisableHandler(const std::string&,
                     }
                 }
             }
+            // 'origin-id' replaces the older parameter 'origin' since Kea 2.5.8
+            // stable release. However, the 'origin' is kept for backward compatibility
+            // with Kea versions before 2.5.8. It is common to receive both parameters
+            // because HA hook library sends both in case the partner server hasn't been
+            // upgraded to the new version. The 'origin-id' takes precedence over the
+            // 'origin'.
+            ConstElementPtr origin_id_element = args->get("origin-id");
             ConstElementPtr origin_element = args->get("origin");
-            // The 'origin' parameter is optional.
-            if (origin_element) {
+            // The 'origin-id' and 'origin' arguments are optional.
+            if (origin_id_element) {
+                if (origin_id_element->getType() == Element::integer) {
+                    type = origin_id_element->intValue();
+                } else {
+                    message << "'origin-id' argument must be a number";
+                }
+            } else if (origin_element) {
                 switch (origin_element->getType()) {
                 case Element::string:
                     origin = origin_element->stringValue();
@@ -621,9 +638,22 @@ ControlledDhcpv4Srv::commandDhcpEnableHandler(const std::string&,
             message << "arguments for the 'dhcp-enable' command must be a map";
 
         } else {
+            // 'origin-id' replaces the older parameter 'origin' since Kea 2.5.8
+            // stable release. However, the 'origin' is kept for backward compatibility
+            // with Kea versions before 2.5.8. It is common to receive both parameters
+            // because HA hook library sends both in case the partner server hasn't been
+            // upgraded to the new version. The 'origin-id' takes precedence over the
+            // 'origin'.
+            ConstElementPtr origin_id_element = args->get("origin-id");
             ConstElementPtr origin_element = args->get("origin");
-            // The 'origin' parameter is optional.
-            if (origin_element) {
+            // The 'origin-id' and 'origin' arguments are optional.
+            if (origin_id_element) {
+                if (origin_id_element->getType() == Element::integer) {
+                    type = origin_id_element->intValue();
+                } else {
+                    message << "'origin-id' argument must be a number";
+                }
+            } else if (origin_element) {
                 switch (origin_element->getType()) {
                 case Element::string:
                     origin = origin_element->stringValue();
@@ -1164,6 +1194,9 @@ ControlledDhcpv4Srv::ControlledDhcpv4Srv(uint16_t server_port /*= DHCP4_SERVER_P
     }
     server_ = this; // remember this instance for later use in handlers
 
+    // ProcessSpawn uses IO service to handle signal set events.
+    ProcessSpawn::setIOService(getIOService());
+
     // TimerMgr uses IO service to run asynchronous timers.
     TimerMgr::instance()->setIOService(getIOService());
 
