@@ -27,6 +27,7 @@ extern const isc::log::MessageID DHCPSRV_CFGMGR_FLQ_POPULATE_FREE_PREFIX_LEASES;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_FLQ_POPULATE_FREE_PREFIX_LEASES_DONE;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_IPV4_RESERVATIONS_NON_UNIQUE_IGNORED;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_IPV6_RESERVATIONS_NON_UNIQUE_IGNORED;
+extern const isc::log::MessageID DHCPSRV_CFGMGR_IP_RESERVATIONS_UNIQUE_DUPLICATES_DETECTED;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_IP_RESERVATIONS_UNIQUE_DUPLICATES_POSSIBLE;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_NEW_SUBNET4;
 extern const isc::log::MessageID DHCPSRV_CFGMGR_NEW_SUBNET6;
@@ -72,6 +73,7 @@ extern const isc::log::MessageID DHCPSRV_HOOK_LEASE4_SELECT_SKIP;
 extern const isc::log::MessageID DHCPSRV_HOOK_LEASE6_EXTEND_SKIP;
 extern const isc::log::MessageID DHCPSRV_HOOK_LEASE6_RECOVER_SKIP;
 extern const isc::log::MessageID DHCPSRV_HOOK_LEASE6_SELECT_SKIP;
+extern const isc::log::MessageID DHCPSRV_HOST_MGR_DB_OPEN_CONNECTION_WITH_RETRY_FAILED;
 extern const isc::log::MessageID DHCPSRV_INVALID_ACCESS;
 extern const isc::log::MessageID DHCPSRV_LEASE4_EXTENDED_INFO_SANITY_FAIL;
 extern const isc::log::MessageID DHCPSRV_LEASE4_EXTENDED_INFO_UPGRADED;
@@ -79,6 +81,7 @@ extern const isc::log::MessageID DHCPSRV_LEASE6_EXTENDED_INFO_SANITY_FAIL;
 extern const isc::log::MessageID DHCPSRV_LEASE6_EXTENDED_INFO_UPGRADED;
 extern const isc::log::MessageID DHCPSRV_LEASE_MGR_CALLBACK_EXCEPTION;
 extern const isc::log::MessageID DHCPSRV_LEASE_MGR_CALLBACK_UNKNOWN_EXCEPTION;
+extern const isc::log::MessageID DHCPSRV_LEASE_MGR_DB_OPEN_CONNECTION_WITH_RETRY_FAILED;
 extern const isc::log::MessageID DHCPSRV_LEASE_SANITY_FAIL;
 extern const isc::log::MessageID DHCPSRV_LEASE_SANITY_FAIL_DISCARD;
 extern const isc::log::MessageID DHCPSRV_LEASE_SANITY_FIXED;
@@ -111,7 +114,6 @@ extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_HOSTNAME6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_HWADDR;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_IAID_DUID;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_IAID_SUBID_DUID;
-extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_LINKADDR6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_PAGE4;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_PAGE6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_RELAYID4;
@@ -122,6 +124,7 @@ extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_SUBID4;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_SUBID6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_SUBID_CLIENTID;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_SUBID_HWADDR;
+extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_SUBID_PAGE6;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_GET_VERSION;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_LEASE_FILE_LOAD;
 extern const isc::log::MessageID DHCPSRV_MEMFILE_LEASE_LOAD;
@@ -169,7 +172,6 @@ extern const isc::log::MessageID DHCPSRV_MYSQL_GET_HOSTNAME6;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_HWADDR;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_IAID_DUID;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_IAID_SUBID_DUID;
-extern const isc::log::MessageID DHCPSRV_MYSQL_GET_LINKADDR6;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_PAGE4;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_PAGE6;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_RELAYID4;
@@ -180,6 +182,7 @@ extern const isc::log::MessageID DHCPSRV_MYSQL_GET_SUBID4;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_SUBID6;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_SUBID_CLIENTID;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_SUBID_HWADDR;
+extern const isc::log::MessageID DHCPSRV_MYSQL_GET_SUBID_PAGE6;
 extern const isc::log::MessageID DHCPSRV_MYSQL_GET_VERSION;
 extern const isc::log::MessageID DHCPSRV_MYSQL_HOST_DB;
 extern const isc::log::MessageID DHCPSRV_MYSQL_HOST_DB_GET_VERSION;
@@ -229,7 +232,6 @@ extern const isc::log::MessageID DHCPSRV_PGSQL_GET_HOSTNAME6;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_HWADDR;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_IAID_DUID;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_IAID_SUBID_DUID;
-extern const isc::log::MessageID DHCPSRV_PGSQL_GET_LINKADDR6;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_PAGE4;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_PAGE6;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_RELAYID4;
@@ -240,6 +242,7 @@ extern const isc::log::MessageID DHCPSRV_PGSQL_GET_SUBID4;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_SUBID6;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_SUBID_CLIENTID;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_SUBID_HWADDR;
+extern const isc::log::MessageID DHCPSRV_PGSQL_GET_SUBID_PAGE6;
 extern const isc::log::MessageID DHCPSRV_PGSQL_GET_VERSION;
 extern const isc::log::MessageID DHCPSRV_PGSQL_HOST_DB;
 extern const isc::log::MessageID DHCPSRV_PGSQL_HOST_DB_GET_VERSION;
